#ifndef NT2_INCLUDE_FUNCTIONS_SCALAR_FIRSTBITSET_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_SCALAR_FIRSTBITSET_HPP_INCLUDED

#include <nt2/bitwise/include/functions/scalar/firstbitset.hpp>

#endif
